#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Super Class for Memo command party
#
# Copyright(C) 2005-, Atzm WATANABE <sitosito@p.chan.ne.jp>
#
# $Id: $

import time
from supercommand import SuperCommand
from common       import ns

class SuperMemo(SuperCommand):
	def __init__(self, config, **positions):
		"""
		super class for memo party:
			positions: each arguments' position, ex. command=0, url=1, title=2, ...
			( url, title and description are used in term of add item )

		Memo processes are:
			Analyze term:
				1. split command line args (SuperCommand scheduled)
				2. append prefix to title
			Modify term:
				1. load rss for parallel process (SuperCommand scheduled)
				2. add args as item to rss object
			Write term:
				1. write out to rss file (SuperCommand defined)
				2. write out to html file (SuperCommand defined)
				(3. notice after write term (SuperCommand defined) )
		"""
		SuperCommand.__init__(self, config, **positions)
		self.append_proc('analyze', 'append_prefix')
		self.append_proc('modify',  'add_item_to_rss')
		self.append_term('write',   ['write_to_rss', 'write_to_html'])

	def _append_prefix(self, c, e, msg, nick, channel):
		"""append prefix to title"""
		try:
			prefix = self.search_regex(self.get_arg('url'))
			if prefix: self.set_arg('title', '[%s] %s' % (prefix, self.get_arg('title')))
		except:
			return False
		return True

	def _add_item_to_rss(self, c, e, msg, nick, channel):
		"""add item to rss"""
		try:
			now   = time.strftime('%Y-%m-%dT%H:%M:%S+09:00', time.localtime())
			url   = self.get_arg('url')
			title = self.get_arg('title')
			description = self.get_arg('description')
			self.add_item(url, title, description, now, nick)
		except:
			return False
		return True

# --- utilities
	def search_regex(self, url):
		"""search prefix for title from config's table"""
		for regexp, prefix in self._config.APPEND_TITLE_TABLE:
			if regexp.search(url): return prefix
		return None
